//Language file: Romană Created by: Iulian Alexe (TotPe.Ro)
if(!window.calendar_languages) {
	window.calendar_languages = {};
}
window.calendar_languages['ro-RO'] = {
	error_noview: 		'Calendar: View-ul {0} nu a fost găsit',
	error_dateformat: 	'Calendar: Format dată greșit {0}. Ar trebui să fie "now" sau "yyyy-mm-dd"',
	error_loadurl: 		'Calendar: URL eveniment nu este setat',
	error_where: 		'Calendar: Direcție de navigare greșită {0}. Nu poate fi decât "next" sau "prev" sau "today"',
	error_timedevide: 	'Calendar: Parametru pentru divizat timpul ar trebui să împartă la 60 fără zecimale. Ceva asemănător cu 10, 15, 30',

	no_events_in_day: 'Nici un eveniment în această zi.',

	title_year: 	'{0}',
	title_month: 	'{0} {1}',
	title_week: 	'luna {0} din {1}',
	title_day: 		'{0} {1} {2}, {3}',

	week:			'Luna {0}',
	all_day:     	'Toată ziua',
	time:        	'Ora',
	events:      	'Evenimente',
	before_time: 	'Se încheie înainte de cronologie',
	after_time:  	'Începe după cronologie',

	m0: 	'Ianuarie',
	m1: 	'Februarie',
	m2: 	'Martie',
	m3: 	'Aprilie',
	m4: 	'Mai',
	m5: 	'Iunie',
	m6: 	'Iulie',
	m7: 	'August',
	m8: 	'Septembrie',
	m9: 	'Octobrie',
	m10: 	'Noiembrie',
	m11: 	'Decembrie',

	ms0: 	'Ian',
	ms1: 	'Feb',
	ms2: 	'Mar',
	ms3: 	'Apr',
	ms4: 	'Mai',
	ms5: 	'Iun',
	ms6: 	'Iul',
	ms7: 	'Aug',
	ms8: 	'Sep',
	ms9: 	'Oct',
	ms10: 	'Nov',
	ms11: 	'Dec',

	d0: 'Duminică',
	d1: 'Luni',
	d2: 'Marți',
	d3: 'Miercuri',
	d4: 'Joi',
	d5: 'Vineri',
	d6: 'Sâmbătă',

	first_day: 1,
	week_numbers_iso_8601: true,

	holidays: {
		'01-01':     "Anul Nou",
		'01-01':     "A DOUA ZI DE ANUL NOU",
		'06-01':     "Botezul Domnului – Boboteaza",
		'07-01':     "Soborul Sfântului Prooroc Ioan Botezătorul şi Înaintemergătorul Domnului",
		'24-01':     "Ziua UNIRII PRINCIPATELOR ROMÂNE",
		'02-02':     "Întâmpinarea Domnului",
		'08-03':     "Ziua Internaţională a Femeii",
		'09-03':     "Sfiinţii 40 de Mucenici",
		'25-03':     "Buna-Vestire",
		'04-04':     "Floriile",
		'18-04':     "Vinerea Mare",
		'easter':    "Paști",
		'easter+1':  "A doua zi de Paşti",
		'easter+2':  "A treia zi de Paşti",
		'01-05':  	 "Ziua internaţională a muncii",
		'24-05':  	 "Naşterea Sfântului Ioan Botezătorul",
		'15-08':  	 "Adormirea Maicii Domnului",
		'29-08':  	 "Tăierea Capului Sfântului Ioan Botezătorul",
		'08-09':  	 "Naşterea Maicii Domnului",
		'14-10':  	 "Sfânta Cuvioasă Parascheva",
		'26-10':  	 "Sfântul Mare Mucenic Dimitrie, Izvorâtorul de Mir",
		'27-10':  	 "Cuviosul Dimitrie cel Nou din Basarabi",
		'08-11':  	 "Soborul Sfinţilor Arhangheli Mihail şi Gavriil",
		'01-12':  	 "Ziua Naţională a României",
		'25-12':  	 "Naşterea Domnului Nostru Iisus Hristos – Crăciunul",
		'26-12':  	 "A doua zi de Crăciun; Soborul Maicii",
		'27-12':  	 "Sfântul Întâiul Mucenic şi Arhidiacon Ştefan"
	}
};
