# -*- coding: utf-8 -*-
# Generated by Django 1.11.2 on 2017-09-04 05:49
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('autoplanner', '0003_auto_20170903_2337'),
    ]

    operations = [
        migrations.AlterField(
            model_name='organization',
            name='current_schedule',
            field=models.ForeignKey(blank=True, default=None, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='current_organizations', to='autoplanner.ScheduleRun'),
        ),
    ]
