{%  load i18n l10n %}<div class="modal-header">
    <button type="button" class="close" data-dismiss="modal" aria-label="Close"><span
            aria-hidden="true">&times;</span>
    </button>
    <h4 class="modal-title">{% trans 'Schedule information' %}</h4>
</div>
<div class="modal-body">
    <table class="table table-striped calendar">
        <tr>
            <th>{% trans 'Agent' %}</th>{% for category in categories %}
            <th>{{ category }}</th>{% endfor %}</tr>
        {% for agent_data in statistics %}
            <tr>
                {% for x in agent_data %}
                    <td>{% if forloop.first %}<strong>{{ x }}</strong>
                        {% else %}{% trans 'tasks: ' %}{{ x.0 }}{% trans ', total time: ' %}{{ x.1|localize }}
                                {% if x.2 %} (corrected value: {{ x.2|localize }}){% endif %}
                    {% endif %}
                    </td>{% endfor %}
            </tr>
        {% endfor %}
    </table>
</div>
<div class="modal-footer">
    <div class="btn-group">
        <button type="button" class="btn btn-default" data-dismiss="modal">{% trans 'Close' %}</button>
    </div>
</div>
