if(!window.calendar_languages) {
        window.calendar_languages = {};
}

window.calendar_languages['hr-HR'] = {
        error_noview:     'Kalendar: Prikaz {0} nije pronađen.',
        error_dateformat: 'Kalendar: Neispravan format datuma {0}. Unesite "now" ili "yyyy-mm-dd"',
        error_loadurl:    'Kalendar: Poveznica događaja nije postavljena.',
        error_where:      'Kalendar: Pogrešan smjer navigacije {0}. Moguće je birati "sljedeće", "prethodno" ili "danas"',
        error_timedevide: 'Kalendar: Rezultat dijeljenja vremena ne smije sadržavati decimalna mjesta. Djelitelj može biti, primjerice, 10, 15, 30.',

        no_events_in_day: 'Nema događanja za današnji dan.',

        title_year:  'Godina {0}.',
        title_month: 'Mjesec {0} {1}. godine',
        title_week:  '{0}. tjedan {1}. godine',
        title_day:   '{0}, {1}. {2} {3}.',

        week:        '{0}. tjedan',
        all_day:     'Cijeli dan',
        time:        'Vrijeme',
        events:      'Događaji i zbivanja',
        before_time: 'Nema završetka',
        after_time:  'Nema početka',

        m0:  'Siječanj',
        m1:  'Veljača',
        m2:  'Ožujak',
        m3:  'Travanj',
        m4:  'Svibanj',
        m5:  'Lipanj',
        m6:  'Srpanj',
        m7:  'Kolovoz',
        m8:  'Rujan',
        m9:  'Listopad',
        m10: 'Studeni',
        m11: 'Prosinac',

        ms0:  'Siječanj',
        ms1:  'Veljača',
        ms2:  'Ožujak',
        ms3:  'Travanj',
        ms4:  'Svibanj',
        ms5:  'Lipanj',
        ms6:  'Srpanj',
        ms7:  'Kolovoz',
        ms8:  'Rujan',
        ms9:  'Listopad',
        ms10: 'Studeni',
        ms11: 'Prosinac',

        d0: 'Nedjelja',
        d1: 'Ponedjeljak',
        d2: 'Utorak',
        d3: 'Srijeda',
        d4: 'Četvrtak',
        d5: 'Petak',
        d6: 'Subota',

        first_day: 1,
        week_numbers_iso_8601: true
};
