if(!window.calendar_languages) {
  window.calendar_languages = {};
}
window.calendar_languages['es-CO'] = {
  error_noview:     'Calendar: Vista {0} no encontrada',
  error_dateformat: 'Calendar: Formato de Fecha Inválido {0}. Debe ser "now" o con el formato "yyyy-mm-dd"',
  error_loadurl:    'Calendar: URL de datos no definida',
  error_where:      'Calendar: Dirección de navegación errónea {0}. Valores válidos: "next" o "prev" o "today"',
  error_timedevide: 'Calendario: parámetro para el separador de hora debe dividir 60 por un entero. Por ejemplo 10, 15, 30',

  title_year:  'Año {0}',
  title_month: '{0} año {1}',
  title_week:  '{0} semana del año {1}',
  title_day:   '{0} {1} {2} año {3}',

  week:        'Semana {0}',
  all_day:     'Todo el día',
  time:        'Hora',
  events:      'Eventos',
  before_time: 'Cita antes de la hora de atención',
  after_time:  'Cita después de la hora de atención',


  m0:  'Enero',
  m1:  'Febrero',
  m2:  'Marzo',
  m3:  'Abril',
  m4:  'Mayo',
  m5:  'Junio',
  m6:  'Julio',
  m7:  'Agosto',
  m8:  'Septiembre',
  m9:  'Octubre',
  m10: 'Noviembre',
  m11: 'Diciembre',

  ms0:  'Ene',
  ms1:  'Feb',
  ms2:  'Mar',
  ms3:  'Abr',
  ms4:  'May',
  ms5:  'Jun',
  ms6:  'Jul',
  ms7:  'Ago',
  ms8:  'Sep',
  ms9:  'Oct',
  ms10: 'Nov',
  ms11: 'Dic',

  d0: 'Domingo',
  d1: 'Lunes',
  d2: 'Martes',
  d3: 'Miércoles',
  d4: 'Jueves',
  d5: 'Viernes',
  d6: 'Sábado',

  easter:       'Semana Santa',
  easterMonday: 'Lunes de Pascua',

  first_day: 1,
  week_numbers_iso_8601: true,

  holidays: {
    // for 2014
    "01-01": "Año Nuevo",
    "06-01": "Día de los Reyes Magos",
    "24-03": "Día de San José",
    "13-04": "Domingo de Ramos",
    "17-04": "Jueves Santo",
    "18-04": "Viernes Santo",
    "20-04": "Domingo de Resurrección",
    "01-05": "Día del Trabajo",
    "02-06": "Día de la Ascensión",
    "23-06": "Corpus Christi",
    "30-06": "Sagrado Corazón",
    "30-06": "San Pedro y San Pablo",
    "20-07": "Día de la Independenci",
    "07-08": "Batalla de Boyaca",
    "18-08": "La asunción de la Virgen",
    "13-10": "Día de la Raza",
    "03-11": "Todos los Santo",
    "17-11": "Independencia de Cartagena",
    "08-12": "Día de la Inmaculada Concepción",
    "25-12": "Día de Navidad"
    /* For 2015
    "01-01": "Año Nuevo",
    "12-01": "Día de los Reyes Magos",
    "23-03": "Día de San José",
    "29-03": "Domingo de Ramos",
    "02-04": "Jueves Santo",
    "03-04": "Viernes Santo",
    "05-04": "Domingo de Resurrección",
    "01-05":  "Día del Trabajo",
    "18-05": "Día de la Ascensión",
    "08-06": "Corpus Christi",
    "15-06": "Sagrado Corazón",
    "29-06": "San Pedro y San Pablo",
    "20-07": "Día de la Independencia",
    "07-08":  "Batalla de Boyacá",
    "17-08": "La asunción de la Virgen",
    "12-10": "Día de la Raza",
    "02-10": "Todos los Santos",
    "16-10": "Independencia de Cartagena",
    "08-12": "Día de la Inmaculada Concepción",
    "25-12": "Día de Navidad"
    */
  }

};
