if(!window.calendar_languages) {
	window.calendar_languages = {};
}
window.calendar_languages['es-DO'] = {
	error_noview:     'Calendario: Vista {0} no encontrada',
	error_dateformat: 'Calendario: Formato de Fecha Inválido {0}. Debe ser "now" o con el formato "yyyy-mm-dd"',
	error_loadurl:    'Calendario: URL de datos no definida',
	error_where:      'Calendario: Dirección de navegación errónea {0}. Valores válidos: "next" o "prev" o "today"',
	error_timedevide: 'Calendario: parámetro para el separador de hora debe dividir 60 por un entero. Por ejemplo 10, 15, 30',

  no_events_in_day: 'No hay eventos hoy',

	title_year:  'Año {0}',
	title_month: '{0} año {1}',
	title_week:  '{0} semana del año {1}',
	title_day:   '{0} {1} {2} año {3}',

	week:        'Semana {0}',
	all_day:     'Todo el día',
	time:        'Tiempo',
	events:      'Eventos',
  before_time: 'Horas previas',
  after_time:  'Horas posteriores',


	m0:  'Enero',
	m1:  'Febrero',
	m2:  'Marzo',
	m3:  'Abril',
	m4:  'Mayo',
	m5:  'Junio',
	m6:  'Julio',
	m7:  'Agosto',
	m8:  'Septiembre',
	m9:  'Octubre',
	m10: 'Noviembre',
	m11: 'Diciembre',

	ms0:  'Ene',
	ms1:  'Feb',
	ms2:  'Mar',
	ms3:  'Abr',
	ms4:  'May',
	ms5:  'Jun',
	ms6:  'Jul',
	ms7:  'Ago',
	ms8:  'Sep',
	ms9:  'Oct',
	ms10: 'Nov',
	ms11: 'Dic',

	d0: 'Domingo',
	d1: 'Lunes',
	d2: 'Martes',
	d3: 'Miércoles',
	d4: 'Jueves',
	d5: 'Viernes',
	d6: 'Sábado',

	easter:       'Pascuas',
	easterMonday: 'Lunes de Pascuas',

	first_day: 2,

	holidays: {
		'01-01': "Año Nuevo",
    '06-01': "Día de los Santos Reyes",
		'21-01': "Día de Nuestra Señora de la Altagracia",
		'26-01': "Día de Duarte",
    '27-02': "Día de la Independencia",
		'01-05': "Viernes Santo",
		'26-05': "Corpus Cristi",
		'16-08': "Día de la Restauración",
		'24-09': "Día de las Mercedes",
    '06-11': "Día de la Constitución",
		'25-12': "Navidad"
	}
};
