if(!window.calendar_languages) {
	window.calendar_languages = {};
}

window.calendar_languages['ms-MY'] = {
	error_noview: 'Kalendar: Paparan {0} tidak wujud',
	error_dateformat: 'Kalendar: Format waktu salah {0}. Seharusnya "now" atau "yyyy-mm-dd"',
	error_loadurl: 'Kalendar: alamat URL tidak wujud',
	error_where: 'Kalendar: Arahan navigasi salah {0}. hanya arahan "next" atau "prev" ataupun "today" sahaja',
	error_timedevide: 'Kalendar: Parameter masa perlu dibahagikan dengan nilai 60 tanpa nilai desimal. Seperti nilai 10, 15, 30',

	no_events_in_day: 'Tiada acara untuk hari ini',

	title_year: '{0}',

	title_month: '{0} {1}',

	title_week: 'minggu {0} daripada {1}',

	title_day: '{0} {1} {2}, {3}',

	week:'Minggu {0}',
	all_day:     'Sepanjang hari',
	time:        'Waktu',
	events:      'Acara',
	before_time: 'Nerakhir sebelum waktu',
	after_time:  'Bermula selepas waktu',

	m0: 'Januari',
	m1: 'Februari',
	m2: 'Mac',
	m3: 'April',
	m4: 'Mei',
	m5: 'Jun',
	m6: 'Julai',
	m7: 'Ogos',
	m8: 'September',
	m9: 'Oktober',
	m10: 'November',
	m11: 'Disember',

	ms0: 'Jan',
	ms1: 'Feb',
	ms2: 'Mac',
	ms3: 'Apr',
	ms4: 'Mei',
	ms5: 'Jun',
	ms6: 'Jul',
	ms7: 'Ogs',
	ms8: 'Sep',
	ms9: 'Okt',
	ms10: 'Nov',
	ms11: 'Dis',

	d0: 'Ahad',
	d1: 'Isnin',
	d2: 'Selasa',
	d3: 'Rabu',
	d4: 'Khamis',
	d5: 'Jumaat',
	d6: 'Sabatu',

	first_day: 1,
	week_numbers_iso_8601: true,
 
	holidays: {
		'18-07-2015':     	'Hari Raya Aidil Fitri 1436 Hijriah',

		'01-01':     				'Sambutan Tahun Baru',
		'01-05':     				'Hari Pekerja',
		'31-08':     				'Hari Kemerdekaan Malaysia (Independence Day)'
	}
};
