{% extends 'base.html' %}
{% load bootstrap3 %}

{% block content %}
    <!-- Main jumbotron for a primary marketing message or call to action -->
    <div class="container">
<ul>{% for organization in organizations %}
    <li><a href="{% url 'organization' organization.pk %}">{{ organization }}</a></li>
{% endfor %}
</ul>
    </div>
{% endblock %}